@@ -12,10 +12,6 @@
  *      notice, this list of conditions and the following disclaimer
  *      in the documentation and/or other materials provided with the
  *      distribution.
- *    * Neither the name of Intel Corporation nor the names of its
- *      contributors may be used to endorse or promote products
- *      derived from this software without specific prior written
- *      permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -98,7 +94,7 @@ file_size(struct file *f, UINT64 *size)
 	return EFI_SUCCESS;
 }
 
-extern EFI_STATUS file_open(CHAR16 *name, struct file **file);
+extern EFI_STATUS file_open(EFI_LOADED_IMAGE *image, CHAR16 *name, struct file **file);
 extern EFI_STATUS file_close(struct file *f);
 
 extern void list_boot_devices(void);
